Etianen.com CMS
===============

A Django-based Content Management System. It is extremely developer-friendly,
and designed to be used as the basis for large, custom web applications.

You'll need to be a Django developer to use this CMS, and there's no one-click
installers. However, if you want something that'll stay out of your way while
providing powerful content management facilities for your editors, you've come
to the right place.

**This is a preview release of an unfinished product. It's stable, secure and
fast, but the API is still subject to change, and the documentation is pretty
thin. Please [contact](mailto:dave@etianen.com) me if you have any questions.**


Licence
-------

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.


More information
----------------

Dave Hall is a freelance web developer, based in Cambridge, UK. You can usually
find him on the Internet in a number of different places:

*   [Website](http://www.etianen.com/ "Dave Hall's homepage")
*   [Blog](http://www.etianen.com/blog/developers/ "Dave Hall's blog")
*   [Twitter](http://twitter.com/etianen "Dave Hall on Twitter")
*   [Google Profile](http://www.google.com/profiles/david.etianen "Dave Hall's Google profile")